echo "new commands" && \
    echo "hello from job 1"

echo "hello from job 1"

wait

#HPC mem=24GB
#HPC module=module1

echo "new commands"
echo "hello from job 2"

wait

#HPC mem
#HPC cpus_per_task=12
#HPC module=jdk/1.8.0_35
#HPC walltime=15:00:00

echo "new commands"
echo "hello from job 4"
echo "new commands" && \
    echo "hello from job 4"
