#!/bin/bash
#
#PBS -N job_3

#PBS -l nodes=1:ppn=12

#PBS -l walltime=15:00:00

#PBS -j oe
#PBS -o localhost:/home/jillian/projects/perl/HPC-Runner-PBS/example/logs/pbs_logs_2015_11_16T06_07_07/job_3.log





    
module load jdk/1.8.0_35
    


cd /home/jillian/projects/perl/HPC-Runner-PBS/example
mcerunner.pl --procs 4 --infile /home/jillian/projects/perl/HPC-Runner-PBS/example/logs/job_3.in --outdir /home/jillian/projects/perl/HPC-Runner-PBS/example/logs --logname job_3
